#ifndef NT2_INCLUDE_FUNCTIONS_RSHR_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_RSHR_HPP_INCLUDED

#include <nt2/bitwise/include/functions/rshr.hpp>

#endif
